@@ -3,20 +3,33 @@ BEGIN {
   $SyForm::Field::Default::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: A default for a field
-$SyForm::Field::Default::VERSION = '0.001';
+$SyForm::Field::Default::VERSION = '0.002';
 use Moose::Role;
-use Moose::Util qw( apply_all_roles );
+use SyForm::Exception::UnexpectedCallToGetValueByArgs;
 use namespace::autoclean;
 
+with qw(
+  SyForm::Field::Process
+);
+
 has default => (
   is => 'ro',
   predicate => 'has_default',
 );
 
-sub BUILD {
-  my ( $self ) = @_;
-  apply_all_roles( $self->syform, 'SyForm::Defaults' ) unless $self->syform->does('SyForm::Defaults');
-}
+around has_value_by_args => sub {
+  my ( $orig, $self, %args ) = @_;
+  return 1 if $self->$orig(%args);
+  return 1 if $self->has_default;
+  return 0;
+};
+
+around get_value_by_args => sub {
+  my ( $orig, $self, %args ) = @_;
+  return $self->$orig(%args) if $self->has_value_by_args(%args);
+  return $self->default if $self->has_default;
+  SyForm::Exception::UnexpectedCallToGetValueByArgs->throw($self);
+};
 
 1;
 
@@ -30,7 +43,7 @@ SyForm::Field::Default - A default for a field
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
