@@ -3,8 +3,9 @@ BEGIN {
   $SyForm::Field::HTML::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: HTML attributes for a field
-$SyForm::Field::HTML::VERSION = '0.001';
+$SyForm::Field::HTML::VERSION = '0.002';
 use Moose::Role;
+use namespace::autoclean;
 
 has html => (
   is => 'rw',
@@ -15,9 +16,14 @@ has html => (
 has input_attrs => (
   is => 'rw',
   isa => 'HashRef[Str|ArrayRef[Str]]',
-  predicate => 'has_input_attrs',
+  lazy_build => 1,
 );
 
+sub _build_input_attrs {
+  my ( $self ) = @_; 
+  return {};
+}
+
 1;
 
 __END__
@@ -30,7 +36,7 @@ SyForm::Field::HTML - HTML attributes for a field
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
