@@ -2,18 +2,17 @@ package SyForm::Field::Readonly;
 BEGIN {
   $SyForm::Field::Readonly::AUTHORITY = 'cpan:GETTY';
 }
-# ABSTRACT: Readonly fields
-$SyForm::Field::Readonly::VERSION = '0.001';
-use Moose::Role;
+# ABSTRACT: TODO
+$SyForm::Field::Readonly::VERSION = '0.002';
+die "TODO";
 
-with qw(
-  SyForm::Field::Default
-);
+use Moose::Role;
+use namespace::autoclean;
 
 has readonly => (
   is => 'ro',
   isa => 'Bool',
-  default => sub { 1 },
+  required => 1,
 );
 
 1;
@@ -24,11 +23,11 @@ __END__
 
 =head1 NAME
 
-SyForm::Field::Readonly - Readonly fields
+SyForm::Field::Readonly - TODO
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 AUTHOR
 
